mistune: Sane and fast Markdown parser with useful plugins and renderers
========================================================================

Description
-----------

Sane and fast Markdown parser with useful plugins and renderers

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/mistune/

